"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const names = require("./names");
class Policy {
    constructor(service, table, value, read, scaleIn, scaleOut, index, stage) {
        this.service = service;
        this.table = table;
        this.value = value;
        this.read = read;
        this.scaleIn = scaleIn;
        this.scaleOut = scaleOut;
        this.index = index;
        this.stage = stage;
        this.dependencies = [];
        this.type = 'AWS::ApplicationAutoScaling::ScalingPolicy';
    }
    setDependencies(list) {
        this.dependencies = list;
        return this;
    }
    toJSON() {
        const nameMetric = names.metric(this.read);
        const nameScalePolicy = names.policyScale(this.service, this.table, this.read, this.index, this.stage);
        const nameTarget = names.target(this.service, this.table, this.read, this.index, this.stage);
        const dependencies = [this.table, nameTarget].concat(this.dependencies);
        return {
            [nameScalePolicy]: {
                DependsOn: dependencies,
                Properties: {
                    PolicyName: nameScalePolicy,
                    PolicyType: 'TargetTrackingScaling',
                    ScalingTargetId: { Ref: nameTarget },
                    TargetTrackingScalingPolicyConfiguration: {
                        PredefinedMetricSpecification: {
                            PredefinedMetricType: nameMetric
                        },
                        ScaleInCooldown: this.scaleIn,
                        ScaleOutCooldown: this.scaleOut,
                        TargetValue: this.value
                    }
                },
                Type: this.type
            }
        };
    }
}
exports.default = Policy;
//# sourceMappingURL=policy.js.map