"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const names = require("./names");
class Role {
    constructor(service, table, index, stage) {
        this.service = service;
        this.table = table;
        this.index = index;
        this.stage = stage;
        this.dependencies = [];
        this.type = 'AWS::IAM::Role';
        this.version = '2012-10-17';
        this.actions = {
            CloudWatch: [
                'cloudwatch:PutMetricAlarm',
                'cloudwatch:DescribeAlarms',
                'cloudwatch:DeleteAlarms',
                'cloudwatch:GetMetricStatistics',
                'cloudwatch:SetAlarmState'
            ],
            DynamoDB: [
                'dynamodb:DescribeTable',
                'dynamodb:UpdateTable'
            ]
        };
    }
    setDependencies(list) {
        this.dependencies = list;
        return this;
    }
    toJSON() {
        const nameRole = names.role(this.service, this.table, this.index, this.stage);
        const namePolicyRole = names.policyRole(this.service, this.table, this.index, this.stage);
        const dependencies = [this.table].concat(this.dependencies);
        const principal = {
            Service: 'application-autoscaling.amazonaws.com'
        };
        const resource = {
            'Fn::Join': ['', ['arn:aws:dynamodb:*:', { Ref: 'AWS::AccountId' }, ':table/', { Ref: this.table }]]
        };
        return {
            [nameRole]: {
                DependsOn: dependencies,
                Properties: {
                    AssumeRolePolicyDocument: {
                        Statement: [
                            { Action: 'sts:AssumeRole', Effect: 'Allow', Principal: principal }
                        ],
                        Version: this.version
                    },
                    Policies: [
                        {
                            PolicyDocument: {
                                Statement: [
                                    { Action: this.actions.CloudWatch, Effect: 'Allow', Resource: '*' },
                                    { Action: this.actions.DynamoDB, Effect: 'Allow', Resource: resource }
                                ],
                                Version: this.version
                            },
                            PolicyName: namePolicyRole
                        }
                    ],
                    RoleName: nameRole
                },
                Type: this.type
            }
        };
    }
}
exports.default = Role;
//# sourceMappingURL=role.js.map