"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const names = require("./names");
class Target {
    constructor(service, table, min, max, read, index, stage) {
        this.service = service;
        this.table = table;
        this.min = min;
        this.max = max;
        this.read = read;
        this.index = index;
        this.stage = stage;
        this.dependencies = [];
        this.type = 'AWS::ApplicationAutoScaling::ScalableTarget';
    }
    setDependencies(list) {
        this.dependencies = list;
        return this;
    }
    toJSON() {
        const resource = ['table/', { Ref: this.table }];
        if (this.index) {
            resource.push('/index/', this.index);
        }
        const nameTarget = names.target(this.service, this.table, this.read, this.index, this.stage);
        const nameRole = names.role(this.service, this.table, this.index, this.stage);
        const nameDimension = names.dimension(this.read, !!this.index);
        const dependencies = [this.table, nameRole].concat(this.dependencies);
        return {
            [nameTarget]: {
                DependsOn: dependencies,
                Properties: {
                    MaxCapacity: this.max,
                    MinCapacity: this.min,
                    ResourceId: { 'Fn::Join': ['', resource] },
                    RoleARN: { 'Fn::GetAtt': [nameRole, 'Arn'] },
                    ScalableDimension: nameDimension,
                    ServiceNamespace: 'dynamodb'
                },
                Type: this.type
            }
        };
    }
}
exports.default = Target;
//# sourceMappingURL=target.js.map